==> nuiton-config-2.6.12-sources.jar: org/nuiton/util/config/ConfigActionDef.java <==
package org.nuiton.util.config;

/*
 * #%L
 * Nuiton Utils :: Nuiton Config
 * $Id: ConfigActionDef.java 2521 2013-03-03 15:20:18Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.6.12/nuiton-config/src/main/java/org/nuiton/util/config/ConfigActionDef.java $
 * %%
 * Copyright (C) 2011 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.io.Serializable;

/**
 * Le contrat de marquage des actions, on utilise cette interface pour
 * caracteriser une action.
 * <p/>
 * Ex :
 * <p/>
 * <pre>
 * public enum MyAppConfigAction implements ConfigActionDef {
 *     HELP(MyAppHelpAction.class.getName() + "#show", "-h", "--help");
 *     public String action;
 *     public String[] aliases;
 *
 *     private WikittyConfigAction(String action, String... aliases) {
 *         this.action = action;
 *         this.aliases = aliases;
 *     }
 *
 *     &#64;Override
 *     public String getAction() {
 *         return action;
 *     }
 *
 *     &#64;Override
 *     public String[] getAliases() {
 *         return aliases;
 *     }
 *
 * }
 * </pre>
 *
 * @author sletellier
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.10
 */
public interface ConfigActionDef extends Serializable {

    /**
     * Must return fully qualified method path : package.Class#method
     *
     * @return action to run
     */
    String getAction();

    /**
     * Return all alias used to execute action.
     *
     * @return aliases used to execute action
     */
    String[] getAliases();
}

==> nuiton-config-2.7-sources.jar: org/nuiton/util/config/ConfigActionDef.java <==
package org.nuiton.util.config;

/*
 * #%L
 * Nuiton Utils :: Nuiton Config
 * $Id: ConfigActionDef.java 2586 2013-07-20 06:57:12Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.7/nuiton-config/src/main/java/org/nuiton/util/config/ConfigActionDef.java $
 * %%
 * Copyright (C) 2011 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.io.Serializable;

/**
 * Le contrat de marquage des actions, on utilise cette interface pour
 * caracteriser une action.
 * <p/>
 * Ex :
 * <p/>
 * <pre>
 * public enum MyAppConfigAction implements ConfigActionDef {
 *     HELP(MyAppHelpAction.class.getName() + "#show", "-h", "--help");
 *     public String action;
 *     public String[] aliases;
 *
 *     private WikittyConfigAction(String action, String... aliases) {
 *         this.action = action;
 *         this.aliases = aliases;
 *     }
 *
 *     &#64;Override
 *     public String getAction() {
 *         return action;
 *     }
 *
 *     &#64;Override
 *     public String[] getAliases() {
 *         return aliases;
 *     }
 *
 * }
 * </pre>
 *
 * @author sletellier
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.10
 * @deprecated since 2.7, use now the http://maven-site.nuiton.org/nuiton-config project, This module will be remove in version 3.0
 */
@Deprecated
public interface ConfigActionDef extends Serializable {

    /**
     * Must return fully qualified method path : package.Class#method
     *
     * @return action to run
     */
    String getAction();

    /**
     * Return all alias used to execute action.
     *
     * @return aliases used to execute action
     */
    String[] getAliases();
}
